@@ -35,13 +35,15 @@ def scan_directory(
 
     Returns:
         List of tuples containing file paths and their relative paths
+        (paths use forward slashes for cross-platform compatibility)
     """
     files = []
 
     try:
         for item in path.iterdir():
             if item.is_file():
-                relative_path = str(item.relative_to(base_path))
+                # Use as_posix() to ensure forward slashes on all platforms
+                relative_path = item.relative_to(base_path).as_posix()
                 files.append((item, relative_path))
             elif item.is_dir():
                 files.extend(scan_directory(item, base_path, out))
@@ -281,10 +283,18 @@ def upload(  # noqa: C901
         files_to_upload = [(local_path, remote_path or local_path.name)]
     else:
         out.info(f"Scanning directory: {local_path}")
-        # Use parent as base_path so the folder name is included in relative paths
-        base_path = local_path.parent if remote_path is None else local_path
+        # Always use parent as base_path so the folder name is included in
+        # relative paths
+        base_path = local_path.parent
         files_to_upload = scan_directory(local_path, base_path, out)
 
+        # If remote_path is specified, prepend it to all relative paths
+        if remote_path:
+            files_to_upload = [
+                (file_path, f"{remote_path}/{rel_path}")
+                for file_path, rel_path in files_to_upload
+            ]
+
     if not files_to_upload:
         out.warning("No files found to upload.")
         return
@@ -292,7 +302,123 @@ def upload(  # noqa: C901
     # Calculate total size
     total_size = sum(f[0].stat().st_size for f in files_to_upload)
 
-    # Display summary
+    if dry_run:
+        # Enhanced dry-run output showing structure
+        if not out.quiet:
+            out.print("\n" + "=" * 70)
+            out.print("DRY RUN - Upload Preview")
+            out.print("=" * 70 + "\n")
+
+            # Show destination
+            out.print("Destination:")
+            if workspace == 0:
+                out.print("  Workspace: Personal (0)")
+            else:
+                workspace_name = None
+                try:
+                    result = client.get_workspaces()
+                    if isinstance(result, dict) and "workspaces" in result:
+                        for ws in result["workspaces"]:
+                            if ws.get("id") == workspace:
+                                workspace_name = ws.get("name")
+                                break
+                except (DrimeAPIError, Exception):
+                    pass
+                if workspace_name:
+                    out.print(f"  Workspace: {workspace_name} ({workspace})")
+                else:
+                    out.print(f"  Workspace: {workspace}")
+
+            # Build the full destination path
+            if current_folder_id is None:
+                base_location = "/"
+            else:
+                if current_folder_name:
+                    base_location = f"/{current_folder_name}"
+                else:
+                    base_location = f"/Folder_{current_folder_id}"
+
+            out.print(f"  Base location: {base_location}")
+
+            # Show where files will actually land
+            if files_to_upload:
+                # Get the first file to show the structure
+                first_rel_path = files_to_upload[0][1]
+                from pathlib import PurePosixPath
+
+                # Extract the top-level folder from the relative path
+                first_parts = PurePosixPath(first_rel_path).parts
+                if len(first_parts) > 1:
+                    top_folder = first_parts[0]
+                    if base_location == "/":
+                        out.print(f"  Files will be uploaded to: /{top_folder}/...")
+                    else:
+                        out.print(
+                            f"  Files will be uploaded to: "
+                            f"{base_location}/{top_folder}/..."
+                        )
+                else:
+                    out.print(f"  Files will be uploaded to: {base_location}")
+
+            out.print("")
+
+            # Extract and show folders that will be created
+            folders_to_create = set()
+            for _, rel_path in files_to_upload:
+                # Use PurePosixPath since rel_path is in POSIX format
+                from pathlib import PurePosixPath
+
+                path_parts = PurePosixPath(rel_path).parts
+                # Build all parent folder paths
+                for i in range(len(path_parts) - 1):  # Exclude the filename
+                    folder_path = str(PurePosixPath(*path_parts[: i + 1]))
+                    folders_to_create.add(folder_path)
+
+            if folders_to_create:
+                sorted_folders = sorted(folders_to_create)
+                out.print(f"Folders to create: {len(sorted_folders)}")
+                for folder in sorted_folders:
+                    out.print(f"  📁 {folder}/")
+                out.print("")
+
+            # Show files to upload with structure
+            out.print(f"Files to upload: {len(files_to_upload)}")
+
+            # Group files by directory for better visualization
+            files_by_dir = {}
+            for file_path, rel_path in files_to_upload:
+                # Use PurePosixPath since rel_path is in POSIX format
+                from pathlib import PurePosixPath
+
+                posix_path = PurePosixPath(rel_path)
+                dir_path = str(posix_path.parent)
+                if dir_path == ".":
+                    dir_path = "(root)"
+                if dir_path not in files_by_dir:
+                    files_by_dir[dir_path] = []
+                file_size = file_path.stat().st_size
+                files_by_dir[dir_path].append((posix_path.name, file_size))
+
+            # Display files grouped by directory
+            for dir_path in sorted(files_by_dir.keys()):
+                if dir_path == "(root)":
+                    out.print("\n  In root:")
+                else:
+                    out.print(f"\n  In {dir_path}/:")
+                for filename, size in sorted(files_by_dir[dir_path]):
+                    out.print(f"    📄 {filename} ({out.format_size(size)})")
+
+            # Summary
+            out.print("\n" + "=" * 70)
+            out.print(
+                f"Total: {len(files_to_upload)} files, {out.format_size(total_size)}"
+            )
+            out.print("=" * 70 + "\n")
+
+        out.warning("Dry run mode - no files were uploaded.")
+        return
+
+    # Display summary for actual upload
     if not out.quiet:
         table_data = []
         for file_path, rel_path in files_to_upload[:10]:  # Show first 10
@@ -319,19 +445,44 @@ def upload(  # noqa: C901
             f"\nTotal: {len(files_to_upload)} files, {out.format_size(total_size)}\n"
         )
 
-    if dry_run:
-        out.warning("Dry run mode - no files were uploaded.")
-        return
+    # Display summary for actual upload
+    if not out.quiet:
+        table_data = []
+        for file_path, rel_path in files_to_upload[:10]:  # Show first 10
+            file_size = file_path.stat().st_size
+            table_data.append(
+                {
+                    "local_path": str(file_path),
+                    "remote_path": rel_path,
+                    "size": out.format_size(file_size),
+                }
+            )
+
+        if len(files_to_upload) > 10:
+            table_data.append(
+                {"local_path": "...", "remote_path": "...", "size": "..."}
+            )
+
+        out.output_table(
+            table_data,
+            ["local_path", "remote_path", "size"],
+            {"local_path": "Local Path", "remote_path": "Remote Path", "size": "Size"},
+        )
+        out.info(
+            f"\nTotal: {len(files_to_upload)} files, {out.format_size(total_size)}\n"
+        )
 
     # Validate uploads and handle duplicates
     try:
         # Validate uploads for duplicates
+        from pathlib import PurePosixPath
+
         validation_files = [
             {
-                "name": Path(rel_path).name,
+                "name": PurePosixPath(rel_path).name,
                 "size": file_path.stat().st_size,
-                "relativePath": str(Path(rel_path).parent)
-                if Path(rel_path).parent != Path(".")
+                "relativePath": str(PurePosixPath(rel_path).parent)
+                if PurePosixPath(rel_path).parent != PurePosixPath(".")
                 else "",
             }
             for file_path, rel_path in files_to_upload
@@ -342,6 +493,13 @@ def upload(  # noqa: C901
                 files=validation_files, workspace_id=workspace
             )
             duplicates = validation_result.get("duplicates", [])
+
+            # Filter out the remote_path from duplicates since it's the target folder
+            # we're uploading INTO, not a new folder we're creating
+            if remote_path and duplicates:
+                # Extract just the top-level folder name from remote_path
+                remote_folder = PurePosixPath(remote_path).parts[0]
+                duplicates = [d for d in duplicates if d != remote_folder]
         except DrimeAPIError:
             # If validation fails, continue without duplicate detection
             duplicates = []
@@ -2209,6 +2367,7 @@ def usage(ctx: Any) -> None:
 
 @main.command()
 @click.argument("path", type=click.Path(exists=True))
+@click.option("--remote-path", "-r", help="Remote destination path")
 @click.option(
     "--workspace",
     "-w",
@@ -2217,7 +2376,9 @@ def usage(ctx: Any) -> None:
     help="Workspace ID (uses default workspace if not specified)",
 )
 @click.pass_context
-def validate(ctx: Any, path: str, workspace: Optional[int]) -> None:  # noqa: C901
+def validate(
+    ctx: Any, path: str, remote_path: Optional[str], workspace: Optional[int]
+) -> None:  # noqa: C901
     """Validate that local files/folders are uploaded with correct size.
 
     PATH: Local file or directory to validate
@@ -2229,6 +2390,7 @@ def validate(ctx: Any, path: str, workspace: Optional[int]) -> None:  # noqa: C9
         pydrime validate drime_test              # Validate folder
         pydrime validate drime_test/test1.txt    # Validate single file
         pydrime validate . -w 5                  # Validate current dir in workspace 5
+        pydrime validate /path/to/local -r remote_folder  # Validate with remote path
     """
     api_key = ctx.obj.get("api_key")
     out: OutputFormatter = ctx.obj["out"]
@@ -2246,13 +2408,41 @@ def validate(ctx: Any, path: str, workspace: Optional[int]) -> None:  # noqa: C9
     try:
         client = DrimeClient(api_key=api_key)
 
+        # Show info about workspace and remote path if not in quiet mode
+        if not out.quiet:
+            # Show workspace information
+            if workspace == 0:
+                out.info("Workspace: Personal (0)")
+            else:
+                # Try to get workspace name
+                workspace_name = None
+                try:
+                    result = client.get_workspaces()
+                    if isinstance(result, dict) and "workspaces" in result:
+                        for ws in result["workspaces"]:
+                            if ws.get("id") == workspace:
+                                workspace_name = ws.get("name")
+                                break
+                except (DrimeAPIError, Exception):
+                    pass
+
+                if workspace_name:
+                    out.info(f"Workspace: {workspace_name} ({workspace})")
+                else:
+                    out.info(f"Workspace: {workspace}")
+
+            if remote_path:
+                out.info(f"Remote path structure: {remote_path}")
+
+            out.info("")  # Empty line for readability
+
         # Collect files to validate
         if local_path.is_file():
-            files_to_validate = [(local_path, local_path.name)]
+            files_to_validate = [(local_path, remote_path or local_path.name)]
         else:
             out.info(f"Scanning directory: {local_path}")
             # Use parent as base_path so the folder name is included in relative paths
-            base_path = local_path.parent
+            base_path = local_path.parent if remote_path is None else local_path
             files_to_validate = scan_directory(local_path, base_path, out)
 
         if not files_to_validate:
